==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/NetworkServiceDesignGroup.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin

import com.pulumi.azurenative.hybridnetwork.kotlin.outputs.NetworkServiceDesignGroupPropertiesFormatResponse
import com.pulumi.azurenative.hybridnetwork.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import com.pulumi.azurenative.hybridnetwork.kotlin.outputs.NetworkServiceDesignGroupPropertiesFormatResponse.Companion.toKotlin as networkServiceDesignGroupPropertiesFormatResponseToKotlin
import com.pulumi.azurenative.hybridnetwork.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [NetworkServiceDesignGroup].
 */
@PulumiTagMarker
public class NetworkServiceDesignGroupResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: NetworkServiceDesignGroupArgs = NetworkServiceDesignGroupArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend NetworkServiceDesignGroupArgsBuilder.() -> Unit) {
        val builder = NetworkServiceDesignGroupArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): NetworkServiceDesignGroup {
        val builtJavaResource =
            com.pulumi.azurenative.hybridnetwork.NetworkServiceDesignGroup(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return NetworkServiceDesignGroup(builtJavaResource)
    }
}

/**
 * network service design group resource.
 * Azure REST API version: 2023-09-01.
 * ## Example Usage
 * ### Create or update the network service design group
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var networkServiceDesignGroup = new AzureNative.HybridNetwork.NetworkServiceDesignGroup("networkServiceDesignGroup", new()
 *     {
 *         Location = "eastus",
 *         NetworkServiceDesignGroupName = "TestNetworkServiceDesignGroupName",
 *         PublisherName = "TestPublisher",
 *         ResourceGroupName = "rg",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/hybridnetwork/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := hybridnetwork.NewNetworkServiceDesignGroup(ctx, "networkServiceDesignGroup", &hybridnetwork.NetworkServiceDesignGroupArgs{
 * 			Location:                      pulumi.String("eastus"),
 * 			NetworkServiceDesignGroupName: pulumi.String("TestNetworkServiceDesignGroupName"),
 * 			PublisherName:                 pulumi.String("TestPublisher"),
 * 			ResourceGroupName:             pulumi.String("rg"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.hybridnetwork.NetworkServiceDesignGroup;
 * import com.pulumi.azurenative.hybridnetwork.NetworkServiceDesignGroupArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var networkServiceDesignGroup = new NetworkServiceDesignGroup("networkServiceDesignGroup", NetworkServiceDesignGroupArgs.builder()
 *             .location("eastus")
 *             .networkServiceDesignGroupName("TestNetworkServiceDesignGroupName")
 *             .publisherName("TestPublisher")
 *             .resourceGroupName("rg")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:hybridnetwork:NetworkServiceDesignGroup TestNetworkServiceDesignGroupName /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.HybridNetwork/publishers/{publisherName}/networkServiceDesignGroups/{networkServiceDesignGroupName}
 * ```
 */
public class NetworkServiceDesignGroup internal constructor(
    override val javaResource: com.pulumi.azurenative.hybridnetwork.NetworkServiceDesignGroup,
) : KotlinCustomResource(javaResource, NetworkServiceDesignGroupMapper) {
    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * network service design group properties.
     */
    public val properties: Output<NetworkServiceDesignGroupPropertiesFormatResponse>
        get() = javaResource.properties().applyValue({ args0 ->
            args0.let({ args0 ->
                networkServiceDesignGroupPropertiesFormatResponseToKotlin(args0)
            })
        })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object NetworkServiceDesignGroupMapper : ResourceMapper<NetworkServiceDesignGroup> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.hybridnetwork.NetworkServiceDesignGroup::class == javaResource::class

    override fun map(javaResource: Resource): NetworkServiceDesignGroup =
        NetworkServiceDesignGroup(
            javaResource as
                com.pulumi.azurenative.hybridnetwork.NetworkServiceDesignGroup,
        )
}

/**
 * @see [NetworkServiceDesignGroup].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [NetworkServiceDesignGroup].
 */
public suspend fun networkServiceDesignGroup(
    name: String,
    block: suspend NetworkServiceDesignGroupResourceBuilder.() -> Unit,
): NetworkServiceDesignGroup {
    val builder = NetworkServiceDesignGroupResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [NetworkServiceDesignGroup].
 * @param name The _unique_ name of the resulting resource.
 */
public fun networkServiceDesignGroup(name: String): NetworkServiceDesignGroup {
    val builder = NetworkServiceDesignGroupResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/NetworkServiceDesignGroup.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin

import com.pulumi.azurenative.hybridnetwork.kotlin.outputs.NetworkServiceDesignGroupPropertiesFormatResponse
import com.pulumi.azurenative.hybridnetwork.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import com.pulumi.azurenative.hybridnetwork.kotlin.outputs.NetworkServiceDesignGroupPropertiesFormatResponse.Companion.toKotlin as networkServiceDesignGroupPropertiesFormatResponseToKotlin
import com.pulumi.azurenative.hybridnetwork.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [NetworkServiceDesignGroup].
 */
@PulumiTagMarker
public class NetworkServiceDesignGroupResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: NetworkServiceDesignGroupArgs = NetworkServiceDesignGroupArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend NetworkServiceDesignGroupArgsBuilder.() -> Unit) {
        val builder = NetworkServiceDesignGroupArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): NetworkServiceDesignGroup {
        val builtJavaResource =
            com.pulumi.azurenative.hybridnetwork.NetworkServiceDesignGroup(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return NetworkServiceDesignGroup(builtJavaResource)
    }
}

/**
 * network service design group resource.
 * Azure REST API version: 2023-09-01.
 * ## Example Usage
 * ### Create or update the network service design group
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var networkServiceDesignGroup = new AzureNative.HybridNetwork.NetworkServiceDesignGroup("networkServiceDesignGroup", new()
 *     {
 *         Location = "eastus",
 *         NetworkServiceDesignGroupName = "TestNetworkServiceDesignGroupName",
 *         PublisherName = "TestPublisher",
 *         ResourceGroupName = "rg",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/hybridnetwork/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := hybridnetwork.NewNetworkServiceDesignGroup(ctx, "networkServiceDesignGroup", &hybridnetwork.NetworkServiceDesignGroupArgs{
 * 			Location:                      pulumi.String("eastus"),
 * 			NetworkServiceDesignGroupName: pulumi.String("TestNetworkServiceDesignGroupName"),
 * 			PublisherName:                 pulumi.String("TestPublisher"),
 * 			ResourceGroupName:             pulumi.String("rg"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.hybridnetwork.NetworkServiceDesignGroup;
 * import com.pulumi.azurenative.hybridnetwork.NetworkServiceDesignGroupArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var networkServiceDesignGroup = new NetworkServiceDesignGroup("networkServiceDesignGroup", NetworkServiceDesignGroupArgs.builder()
 *             .location("eastus")
 *             .networkServiceDesignGroupName("TestNetworkServiceDesignGroupName")
 *             .publisherName("TestPublisher")
 *             .resourceGroupName("rg")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:hybridnetwork:NetworkServiceDesignGroup TestNetworkServiceDesignGroupName /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.HybridNetwork/publishers/{publisherName}/networkServiceDesignGroups/{networkServiceDesignGroupName}
 * ```
 */
public class NetworkServiceDesignGroup internal constructor(
    override val javaResource: com.pulumi.azurenative.hybridnetwork.NetworkServiceDesignGroup,
) : KotlinCustomResource(javaResource, NetworkServiceDesignGroupMapper) {
    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * network service design group properties.
     */
    public val properties: Output<NetworkServiceDesignGroupPropertiesFormatResponse>
        get() = javaResource.properties().applyValue({ args0 ->
            args0.let({ args0 ->
                networkServiceDesignGroupPropertiesFormatResponseToKotlin(args0)
            })
        })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object NetworkServiceDesignGroupMapper : ResourceMapper<NetworkServiceDesignGroup> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.hybridnetwork.NetworkServiceDesignGroup::class == javaResource::class

    override fun map(javaResource: Resource): NetworkServiceDesignGroup =
        NetworkServiceDesignGroup(
            javaResource as
                com.pulumi.azurenative.hybridnetwork.NetworkServiceDesignGroup,
        )
}

/**
 * @see [NetworkServiceDesignGroup].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [NetworkServiceDesignGroup].
 */
public suspend fun networkServiceDesignGroup(
    name: String,
    block: suspend NetworkServiceDesignGroupResourceBuilder.() -> Unit,
): NetworkServiceDesignGroup {
    val builder = NetworkServiceDesignGroupResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [NetworkServiceDesignGroup].
 * @param name The _unique_ name of the resulting resource.
 */
public fun networkServiceDesignGroup(name: String): NetworkServiceDesignGroup {
    val builder = NetworkServiceDesignGroupResourceBuilder()
    builder.name(name)
    return builder.build()
}
